Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1533)

Unified Diff: chrome/browser/download/download_util.h

Issue 164459: Implement drag and drop of downloads for the Mac downloads page (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/dom_ui/downloads_dom_handler.cc ('k') | chrome/browser/download/download_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/download/download_util.h
===================================================================
--- chrome/browser/download/download_util.h (revision 23544)
+++ chrome/browser/download/download_util.h (working copy)
@@ -11,6 +11,7 @@
#include <string>
#include "base/basictypes.h"
+#include "base/gfx/native_widget_types.h"
#include "base/task.h"
#if defined(OS_WIN) || defined(TOOLKIT_VIEWS)
@@ -119,12 +120,15 @@
double animation_progress,
PaintDownloadProgressSize size);
-#if defined(OS_WIN) || defined(TOOLKIT_VIEWS)
+#if defined(OS_WIN) || defined(TOOLKIT_VIEWS) || defined(OS_MACOSX)
// Drag support ----------------------------------------------------------------
// Helper function for download views to use when acting as a drag source for a
-// DownloadItem. If 'icon' is NULL, no image will be accompany the drag.
-void DragDownload(const DownloadItem* download, SkBitmap* icon);
+// DownloadItem. If |icon| is NULL, no image will be accompany the drag. |view|
+// is only required for Mac OS X, elsewhere it can be NULL.
+void DragDownload(const DownloadItem* download,
+ SkBitmap* icon,
+ gfx::NativeView view);
#endif
// Executable file support -----------------------------------------------------
« no previous file with comments | « chrome/browser/dom_ui/downloads_dom_handler.cc ('k') | chrome/browser/download/download_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698